import os
import shutil
from pathlib import Path
from .setupSslserver import findReplaceAt

def setup_quick():
    source_path = Path(__file__).resolve()
    print("copying....", end="")
    shutil.copytree(os.path.join(source_path.parent.parent, "temp"), os.path.join(Path.cwd(), "temp"))
    shutil.copytree(os.path.join(source_path.parent.parent, "test"), os.path.join(Path.cwd(), "test"))
    shutil.copy2(os.path.join(source_path.parent, "main-setup.py"), os.path.join(Path.cwd()))
    shutil.copy2(os.path.join(source_path.parent, "main.py"), os.path.join(Path.cwd()))
    # shutil.copy2(os.path.join(source_path.parent, "setup-django-sslserver.py"), os.path.join(Path.cwd()))
    shutil.copy2(os.path.join(source_path.parent, "setupSslserver.py"), os.path.join(Path.cwd()))
    # shutil.copy2(os.path.join(source_path.parent, "setup_heroku.py"), os.path.join(Path.cwd()))
    print("DONE")

    os.system("python main-setup.py --project main")
    os.system("python main-setup.py --cred")
    os.system("python main-setup.py --app main,dataStorage --reg main,dataStorage.apps.DatastorageConfig --url main,dataStorage")
    os.system("python main-setup.py --reg main,sslserver")
    os.system("python main-setup.py --reg main,registration")
    os.system("python main-setup.py --reg main,crispy_forms")
    os.system("python main-setup.py --reg main,rest_framework")
    os.system("python main-setup.py --reg main,rest_framework.authtoken")
    os.system("python main-setup.py --reg main,knox")
    os.system("python main-setup.py --copy temp/static,src/static --copy temp/templates,src/templates")
    # os.system("python main-setup.py --replace src/main/urls.py,]\n,\tpath\('accounts/',include\('registration.backends.simple.urls'\)\),\n")
    findReplaceAt(os.path.join("src", "main", "urls.py"), "]\n", "\tpath('accounts/', include('registration.backends.simple.urls')),\n")
    os.system("python main-setup.py --folder src/media")
    os.system("python main-setup.py --touch src/media/.nomedia")
    os.system("python main-setup.py --heroku main,python-3.11.1")
    os.system("python main-setup.py --clean")
    os.system("python main-setup.py --secure main")
    os.system("python main-setup.py --setup")
    os.system("python main-setup.py --signal dataStorage")
    try:
        shutil.rmtree("temp")
        shutil.rmtree("test")
        # os.remove("main.py")
        # os.remove("main-setup.py")
        # os.remove("setupSslserver.py")
        # os.remove("setup_heroku.py")
        # os.remove("setup-django-sslserver.py")
    except:
        pass
    os.system("python main-setup.py --run 2")



import requests
import unittest
import ast, json, subprocess

class TestApiSimple(unittest.TestCase):

    def setUp(self):
        self.payload = {
            'username' : 'django',
            'password' : 'space',
        }

    def test_api_token(self):
        with requests.Session() as session:
            res = session.post(
                'https://127.0.0.1:8000/api/login/',
                data    = self.payload,
                verify  = False
            )
            # print(res.content)
            self.assertEqual(res.status_code, 200)
            token = ast.literal_eval(res.content.decode("UTF-8"))['token']
            res = session.get(
                'https://127.0.0.1:8000/api/home/',
                verify  = False,
                headers = {"Authorization":f"Token {token}"}
            )
            # print(res.status_code)
            self.assertEqual(res.status_code, 200)
            # print(res.content.decode("UTF-8"))
            res = session.post(
                'https://127.0.0.1:8000/api/logoutall/',
                verify  = False,
                headers = {"Authorization":f"Token {token}"}
            )
            # print(res.status_code)
            self.assertEqual(res.status_code, 204)

    def test_rfapi_token(self):
        with requests.Session() as session:
            res = session.post(
                'https://127.0.0.1:8000/api/rflogin/',
                data = self.payload,
                verify=False
            )
            self.assertEqual(res.status_code, 200)
            token = json.loads(res.content)['knoxToken']
            res = session.get(
                'https://127.0.0.1:8000/api/home/',
                verify=False,
                headers={"Authorization":f"Token {token}"}
            )
            self.assertEqual(res.status_code, 200)
            # print(res.status_code)
            # print(res.content.decode("UTF-8"))
            res = session.post(
                'https://127.0.0.1:8000/api/logoutall/',
                verify=False,
                headers={"Authorization":f"Token {token}"}
            )
            self.assertEqual(res.status_code, 204)
            # print(res.status_code)

if __name__ == '__main__':
    unittest.main()



import subprocess, os

def touch(file, content=""):
    with open(file, 'w') as fp:
        fp.write(content)
        pass

def install(package):#python -m pipenv install <name(s)>
    subprocess.run(['python', '-m', 'pipenv', 'install', package])
    os.system("python -m pipenv run pip freeze > requirments.txt")
    #subprocess.run(['python', '-m', 'pipenv', 'run', 'pip', 'freeze', '>', 'requirments.txt'])

def setup(name):
    touch('Procfile', 'web: gunicorn --pythonpath src '+name+'.wsgi --log-file -')
    touch('env.txt', 'DISABLE_COLLECTSTATIC = 1')
    lines = []
    with open(os.path.join("src", name, "settings.py"), 'r') as fp:
        lines = fp.readlines()
    index = lines.index("    'django.middleware.security.SecurityMiddleware',\n")
    lines[index] = lines[index]+"\t'whitenoise.middleware.WhiteNoiseMiddleware',\n"
    with open(os.path.join("src", name, "settings.py"), 'w') as fp:
        fp.writelines(lines)


if __name__ == '__main__':
    install('whitenoise')
    install('gunicorn')
    setup('main')
